@@ -36,7 +36,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "0.9.1"
+__version__ = "0.9.2"
 
 
 def create_app(
@@ -80,6 +80,17 @@ def create_app(
     if not disable_gzip:
         app.add_middleware(GZipMiddleware, minimum_size=5000)
 
+    if settings.SECURE:
+        from secure import SecureHeaders, SecureCookie
+
+        secure_headers = SecureHeaders()
+
+        @app.middleware("http")
+        async def set_secure_headers(request, call_next):
+            response = await call_next(request)
+            secure_headers.starlette(response)
+            return response
+
     @app.on_event("startup")
     async def on_start_app() -> None:
         await start_app(app)
@@ -115,8 +126,8 @@ async def start_app(app: FastAPI):
             setup_gitlab(app)
         except ValueError as err:
             logger.error(
-                "Gitlab dependencies are missing, if you are planning to use workflows make sure the optional "
-                + "dependencies are installed"
+                "Gitlab dependencies are missing, if you are planning to use workflows make sure the optional"
+                + " dependencies are installed"
             )
             raise err  # App probably doesn't want to use gitlab
 
