@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, Tuple, Type
+from typing import Any, List, Optional, Tuple, Type, Literal
 
 from google.cloud.exceptions import NotFound
 from google.cloud.firestore import Client, CollectionReference, Query
@@ -113,11 +113,9 @@ class FirestoreClient(BaseClient):
 
     #     return WriteResult()
 
-    async def get(
-        self, model: Type[DocumentDBModel], _id: str, session: Any = None
-    ) -> Optional[DocumentDBModel]:
-
-        collection_name = model.get_db_collection()
+    async def get_dict(
+        self, collection_name: str, _id: str, session: Any = None,
+    ) -> Optional[dict]:
         collection = self.get_collection(collection_name)
 
         result = await force_async(collection.document(_id).get)()
@@ -125,16 +123,25 @@ class FirestoreClient(BaseClient):
         if not result.exists:
             return None
 
-        return model(**result.to_dict())
+        return result.to_dict()
 
-    async def find_one(
-        self,
-        model: Type[DocumentDBModel],
-        where: List[WhereCondition] = [],
-        session: Any = None,
+    async def get(
+        self, model: Type[DocumentDBModel], _id: str, session: Any = None
     ) -> Optional[DocumentDBModel]:
 
         collection_name = model.get_db_collection()
+        result = await self.get_dict(collection_name, _id, session)
+        if result is None:
+            return None
+        return model(**result)
+
+    async def find_one_dict(
+        self,
+        collection_name: str,
+        where: List[WhereCondition] = [],
+        session: Any = None,
+    ) -> Optional[dict]:
+
         collection = self.get_collection(collection_name)
         query_ref = collection
         for wc in where:
@@ -145,23 +152,32 @@ class FirestoreClient(BaseClient):
 
         for res in result:
             LOG.debug(f"Find One Result: {res.to_dict()}")
-            item = model(**res.to_dict())
-            item.id = res.id
-            return item
+            return res.to_dict()
 
         return None
 
-    async def list(
+    async def find_one(
         self,
         model: Type[DocumentDBModel],
         where: List[WhereCondition] = [],
+        session: Any = None,
+    ) -> Optional[DocumentDBModel]:
+
+        collection_name = model.get_db_collection()
+        result = await self.find_one_dict(collection_name, where, session)
+        if result is not None:
+            return model(**result)
+        return None
+
+    async def list_dict(
+        self,
+        collection_name: str,
+        where: List[WhereCondition] = [],
         _limit: int = 0,
         _sort: List[Tuple[str, SortOrder]] = None,
         mongo_offset: int = 0,
         fire_offset: FireOffset = None,
-    ) -> List[DocumentDBModel]:
-
-        collection_name = model.get_db_collection()
+    ) -> List[dict]:
         collection = self.get_collection(collection_name)
         offset_value = None
         if fire_offset is not None:
@@ -190,11 +206,27 @@ class FirestoreClient(BaseClient):
 
         results = await force_async(query_ref.stream)()
 
-        models: List[DocumentDBModel] = []
+        res_list = []
         for res in results:
+            res_list.append(res.to_dict())
+        return res_list
 
-            models.append(model(**res.to_dict()))
-        return models
+    async def list(
+        self,
+        model: Type[DocumentDBModel],
+        where: List[WhereCondition] = [],
+        _limit: int = 0,
+        _sort: List[Tuple[str, SortOrder]] = None,
+        mongo_offset: int = 0,
+        fire_offset: FireOffset = None,
+    ) -> List[DocumentDBModel]:
+
+        collection_name = model.get_db_collection()
+        results = await self.list_dict(
+            collection_name, where, _limit, _sort, mongo_offset, fire_offset
+        )
+
+        return [model(**res) for res in results]
 
     async def create_indexes(self, index=List[DBIndex]) -> Optional[List[str]]:
         return None
