@@ -1,7 +1,7 @@
 import asyncio
 import datetime
 from io import BytesIO
-from typing import List, Optional, Union
+from typing import List, Optional, Union, Iterator
 
 from fastapi import UploadFile
 from google.cloud import storage
@@ -10,7 +10,6 @@ from google.cloud.storage.bucket import Blob, Bucket
 
 from fa_common import (
     StorageError,
-    FileDownloadRef,
     force_async,
     get_current_app,
     get_settings,
@@ -87,7 +86,7 @@ class GoogleStorageClient(BaseClient):
         bucket = await self._get_bucket(bucket_name)
         return bucket.blob(self.convert_path_in(path, bucket_name))
 
-    async def _list_blobs(self, bucket_name, prefix) -> List[Blob]:
+    async def _list_blobs(self, bucket_name, prefix) -> Iterator[Blob]:
         bucket = await self._get_bucket(bucket_name)
         return await force_async(bucket.list_blobs)(
             prefix=self.convert_path_in(prefix, bucket_name)
@@ -223,8 +222,15 @@ class GoogleStorageClient(BaseClient):
         try:
             if recursive:
                 blobs = await self._list_blobs(bucket_name, file_path)
-                futures = [self._delete_blob(blob) for blob in blobs]
-                await asyncio.wait(futures)
+                futures = []
+                for blob in blobs:
+                    futures.append(self._delete_blob(blob))
+                if futures:
+                    await asyncio.wait(futures)
+                else:
+                    raise StorageError(
+                        f"Trying to delete a folder {bucket_name}/{file_path} that doesn't exist."
+                    )
             else:
                 blob = await self._get_blob(bucket_name, file_path)
                 await self._delete_blob(blob)
