@@ -190,6 +190,8 @@ class GitlabClient:
 
         job_run = JobRun(
             id=job.id,
+            workflow_id=job.pipeline["id"],
+            workflow_status=job.pipeline["status"],
             status=job.status,
             started_at=job.started_at,
             finished_at=job.finished_at,
